==> bb-1.2a.tgz: bb/etc/bbinc.sh <==
#/bin/sh
#
# bbinc.sh
#
# Sean MacGuire - The MacLawran Group Inc. 
# Version 1.2a
# May 4th, 1999
# 
# This program is Copyright (c) 1997-1999
# The MacLawran Group Inc. 
# All Rights Reserved 
#

BBREL="1.2a"
BBRELDATE="Tue, 04 May 1999 23:00:00 GMT"
export BBREL BBRELDATE

# --------------------------------------------------
# Big Brother - Pager codes and system definitions
#
# NO CHANGES SHOULD BE NEEDED HERE
# --------------------------------------------------
#
BB="${BBHOME}/bin/bb"			# WHERE bb LIVES
BBHOSTS="${BBHOME}/etc/bb-hosts"        # BIG BROTHER HOSTS FILE
BBDFTAB="${BBHOME}/etc/bb-dftab"	# LEVELS BY DISK PARTITION
BBLOGS="${BBHOME}/www/logs"             # WHERE THE LOG FILES LIVE
BBNOTES="${BBHOME}/www/notes"           # WHERE THE SYSTEM NOTES LIVE
export BB BBHOSTS BBDFTAB BBLOGS BBNOTES

NETERR="7"				# NETWORK ERROR 7 + PORT NUMBER
					# KEEP FOR BACKWARD COMPATABILITY
export NETERR

#
# FIGURE OUT THE LOCAL MACHINE NAME
# USE FULLY QUALIFIED MACHINE NAMES?
# DOT -> COMMA -> DOT FOR WEB DISPLAY
#

MACHINE=`uname -n`			# WHO ARE WE?  MAY NOT BE FQDN!

# New code 1.09 - RAC
#
# Extract the host part if not FQDN
if test "$FQDN" != "TRUE"
then
	set `echo $MACHINE | $SED "s/\./ /"` >/dev/null 2>&1
	MACHINE=$1
fi

set ""		# force a set or it will keep the old $* if it failed

# Do we match: "255.255.255.255 ${MACHINE}" ?
set `$GREP -i "^[0-9][0-9\.]*[ 	][ 	]*${MACHINE}$" $BBHOSTS` >/dev/null 2>&1
if test "$2" = ""
then
	# Do we match: "255.255.255.255 ${MACHINE} # blah blah blah" ?
	# Do we match: "255.255.255.255 ${MACHINE}.domain.com # blah blah blah" ?
	set `$GREP -i "^[0-9][0-9\.]*[ 	][ 	]*${MACHINE}[\. 	].*$" $BBHOSTS` >/dev/null 2>&1
fi

if test "$2" = ""
then
	echo "This host <${MACHINE}> was not found in the etc/bb-hosts file"
	echo "Please use the same name from 'uname -n'"
	exit 1
fi
# End of new code 1.09 - RAC

# SMM 1.09 - OFFLOAD CODE FROM RUNBB.SH 
# CHECK IF THIS MACHINE IS A BBDISPLAY

# echo "TESTING RESULTS FROM $*"

echo "$*" | $GREP BBDISPLAY > /dev/null 2>&1 
if test "$?" = "0"
then
	BBDISPLAY="TRUE"
	BBSERVER="TRUE"
fi

echo "$*" | $GREP BBPAGER > /dev/null 2>&1 
if test "$?" = "0"
then
	BBPAGER="TRUE"
	BBSERVER="TRUE"
fi

echo "$*" | $GREP BBNET > /dev/null 2>&1 
if test "$?" = "0"
then
	BBNET="TRUE"
fi

export BBDISPLAY BBSERVER BBNET

MACHINE=$2				# GET FQDN NAME FROM etc/bb-hosts
MACHIP=`echo $1 | $SED "s/\.//g"`	# IP ADDRESS FOR PAGER DISPLAY

if test "$FQDN" = "TRUE"
then
	MACHINE=`echo $MACHINE | $SED "s/\./,/g"`
else
	set `echo $MACHINE | $SED "s/\./ /"`
	MACHINE=$1
fi

export MACHINE MACHIP

#
# WHERE THE BIG BROTHER SERVERS LIVE
# LOOK IN bb-hosts FOR DISPLAY AND PAGER HOSTS
#
BBDISP=`$GREP BBDISPLAY $BBHOSTS | $GREP -v "^\#"`
if test "$BBDISP" = ""
then
	echo "BBDISPLAY NOT SET IN $BBHOSTS - Big Brother won't work!" 
	exit 1
else
	set $BBDISP
	if test "$1" = "0.0.0.0"		# SMM 1.10 DDNS SUPPORT
	then
		BBDISP=$2			# USE THE NAME
	else
		BBDISP=$1			# IP ADDRESS OF THE BB DISPLAY
	fi
fi

BBPAGE=`$GREP BBPAGER $BBHOSTS | $GREP -v "^\#"`
if test "$BBPAGE" = ""
then
	BBPAGE=$BBDISP			# SENSIBLE DEFAULT
else
	set $BBPAGE
	if test "$1" = "0.0.0.0"		# SMM 1.10 DDNS SUPPORT
	then
		BBPAGE=$2			# USE THE NAME
	else
		BBPAGE=$1			# GET THE IP ADDR OF THE PAGER
	fi
fi

export BBDISP BBPAGE

#
# GET PAGELEVELS FROM etc/bbwarnsetup.cfg. IT CONTAINS THE COLOR
# ON WHICH A NOTIFICATION SHOULD BE SENT
# IF YOU CHANGE THE VALUE pagelevels IN etc/bbwarnsetup.cfg YOU
# MUST RESTART BB.  MAKE SURE THE pagelevels VALUE IS
# IDENTICAL ON ALL CLIENTS
# Default colors are in bbdef.sh

pagelevelsline=`grep "^pagelevels:" $BBHOME/etc/bbwarnsetup.cfg` 2>/dev/null
if [ "$?" -eq 0 ]
then
        set $pagelevelsline >/dev/null 2>&1
        if [ "$#" -gt 1 ]
        then
                shift           # remove pagelevels token from line
                param="$*"

                # Check if it's a valid parameter, remove bad values

                PAGELEVELS=""
                for color in $param
                do
                        case $color in  
      
                        yellow | red | purple )

                                PAGELEVELS="$PAGELEVELS $color"
                                ;;

                        * )
                                ;;

                        esac
                done
        fi
fi
export PAGELEVELS

#echo "=====> $MACHINE $MACHIP $BBDISP $BBPAGE"

==> bb-1.08a.tgz: bb/etc/bbinc.sh <==
#!/bin/sh

# --------------------------------------------------
# Big Brother - Pager codes and system definitions
#
# NO CHANGES SHOULD BE NEEDED HERE
# --------------------------------------------------
#

BB="${BBHOME}/bin/bb"			# WHERE bb LIVES
BBHOSTS="${BBHOME}/etc/bb-hosts"        # BIG BROTHER HOSTS FILE
BBDFTAB="${BBHOME}/etc/bb-dftab"	# LEVELS BY DISK PARTITION
BBLOGS="${BBHOME}/www/logs"             # WHERE THE LOG FILES LIVE
BBNOTES="${BBHOME}/www/notes"           # WHERE THE SYSTEM NOTES LIVE
export BB BBHOSTS BBDFTAB BBLOGS BBNOTES

#
# IF NO PAGER NUMBER IS DEFINED, THEN DISABLE PAGING
#
if test "$PAGER" = ""
then
	DFPAGE=N			# PAGE ON DISK FULL (Y/N)
	CPUPAGE=N			# PAGE FOR CPU Y/N
	TELNETPAGE=N			# PAGE ON TELNET FAILURE?
	HTTPPAGE=N			# PAGE ON HTTP FAILURE?
fi

#
# PAGER ERROR CODES (THESE SHOULDN'T BE ADJUSTED)
#
DISKERR="100"				# DISK ERROR CODES FOR PAGER
CPUERR="200"				# CPU LOAD ERROR CODES
PROCERR="300"				# PROCESSES ERROR CODES
MSGERR="400"				# MESSAGES ERROR CODE
TELNETERR="500"				# TELNET ERROR CODE
HTTPERR="600"				# HTTP ERROR CODE
NETERR="7"				# NETWORK ERROR 7 + PORT NUMBER
DNSERR="800"				# DNS ERROR
export DISKERR CPUERR PROCERR MSGERR TELNETERR HTTPERR NETERR DNSERR


#
# FIGURE OUT THE LOCAL MACHINE NAME
# USE FULLY QUALIFIED MACHINE NAMES?
# DOT -> COMMA -> DOT FOR WEB DISPLAY
#
MACHINE=`uname -n`			# WHO ARE WE?  MAY NOT BE FQDN!
set `$GREP $MACHINE $BBHOSTS`
MACHINE=$2				# GET FQDN NAME FROM etc/bb-hosts
MACHIP=`echo $1 | $SED "s/\.//g"`	# IP ADDRESS FOR PAGER DISPLAY

if test "$FQDN" = "TRUE"
then
	MACHINE=`echo $MACHINE | $SED "s/\./,/g"`
else
	set `echo $MACHINE | $SED "s/\./ /"`
	MACHINE=$1
fi

export MACHINE MACHIP

#
# WHERE THE BIG BROTHER SERVERS LIVE
# LOOK IN bb-hosts FOR DISPLAY AND PAGER
#
BBDISP=`$GREP BBDISPLAY $BBHOSTS`
if test "$BBDISP" = ""
then
	echo "BBDISPLAY NOT SET IN $BBHOSTS - Big Brother won't work!" 
	exit 1
else
	set $BBDISP
	BBDISP=$1			# IP ADDRESS OF THE BB DISPLAY
fi

BBPAGE=`$GREP BBPAGER $BBHOSTS`
if test "$BBPAGE" = ""
then
	BBPAGE=$BBDISP			# SENSIBLE DEFAULT
else
	set $BBPAGE
	BBPAGE=$1			# GET THE IP ADDR OF THE PAGER
fi

export BBDISP BBPAGE

#echo "=====> $MACHINE $MACHIP $BBDISP $BBPAGE"
